@@ -15,7 +15,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': 'libpython3.11.dll.a',
- 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -pipe -pipe',
+ 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
@@ -34,7 +34,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-pipe',
+ 'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-cygwin' "
@@ -46,13 +46,13 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=x86_64-pc-cygwin' 'host_alias=x86_64-pc-cygwin' "
                 "'PKG_CONFIG_PATH=/usr/lib/pkgconfig:/usr/share/pkgconfig:/lib/pkgconfig' "
                 "'CC=gcc' 'CFLAGS=-march=nocona -msahf -mtune=generic -O2 "
-                "-pipe' 'LDFLAGS=-pipe' 'CPPFLAGS='",
+                "-pipe' 'LDFLAGS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/c/S/B/src/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/c/S/B/src/Python-3.11.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/c/S/B/src/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/c/S/B/src/Python-3.11.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -605,11 +605,11 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
- 'LDFLAGS': '-pipe -pipe',
+ 'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.dll.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -pipe -pipe',
+ 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.11',
@@ -866,7 +866,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MULTIARCH': 'x86_64-msys',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-msys\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
- 'NO_AS_NEEDED': '',
+ 'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
@@ -925,13 +925,13 @@ build_time_vars = {'ABIFLAGS': '',
                    '-mtune=generic -O2 -pipe -std=c11 '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-pipe -pipe',
+ 'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-pipe -pipe',
+ 'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-pipe -pipe',
+ 'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -1029,8 +1029,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/c/S/B/src/Python-3.11.8',
- 'abs_srcdir': '/c/S/B/src/Python-3.11.8',
+ 'abs_builddir': '/c/S/B/src/Python-3.11.9',
+ 'abs_srcdir': '/c/S/B/src/Python-3.11.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
